import { API } from "./Constants"
import { getSession, saveSession, Session } from "./api/session.ts"
import { redirect } from "react-router-dom"

export async function fetchAPI(
    url: string,
    payload: unknown,
    method = "POST",
    redirectIfUnauthorized: boolean = true,
): Promise<Response> {
    const session = getSession()
    const token = session?.auth?.token

    const headers: HeadersInit = {
        Accept: "application/json",
        "Content-Type": "application/json",
    }

    if (token) {
        headers.Authorization = token
    }

    const response = await fetch(`${API}/${url}`, {
        method,
        headers,
        body: JSON.stringify(payload),
    })

    return await handleResponse(session, response, redirectIfUnauthorized)
}

export async function fetchAPIGet(
    url: string,
    redirectIfNotAuth: boolean = true,
): Promise<Response> {
    const session = getSession()
    const token = session?.auth?.token

    const headers: HeadersInit = {
        Accept: "application/json",
        "Content-Type": "application/json",
    }

    if (token) {
        headers.Authorization = token
    }

    const response = await fetch(`${API}/${url}`, {
        method: "GET",
        headers,
    })

    return await handleResponse(session, response, redirectIfNotAuth)
}

async function handleResponse(
    session: Session,
    response: Response,
    redirectIfNotAuth: boolean,
): Promise<Response> {
    // if we provided a token but still unauthorized, the token has expired
    if (response.status == 401) {
        if (!redirectIfNotAuth) return response
        redirect("/login")
        saveSession({ ...session, urlTarget: location.pathname })
        return response
    }

    const nextToken = response.headers.get("Next-Authorization")!
    const expirationDate = Date.parse(
        response.headers.get("Next-Authorization-Expiration-Date")!,
    )
    saveSession({ ...session, auth: { token: nextToken, expirationDate } })

    return response
}
